@@ -3,25 +3,26 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "2.1.9" or
-    raise "ruby lib version (2.1.9) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.2.10"[/^[0-9]+[.][0-9]+[.]/]) or
+    raise "ruby lib version (2.2.10) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.1/2.1.0/x86_64-darwin12")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.2/2.2.0/x86_64-darwin12")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "1"
+  CONFIG["MINOR"] = "2"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "490"
+  CONFIG["PATCHLEVEL"] = "489"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "ruby2.1"
-  CONFIG["RUBY_INSTALL_NAME"] = "ruby2.1"
-  CONFIG["RUBY_SO_NAME"] = "ruby.2.1.0"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.2"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.2"
+  CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(MAJOR).$(MINOR).$(TEENY)"
+  CONFIG["DESTDIR"] = ""
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.1.pc"
+  CONFIG["ruby_pc"] = "ruby-2.2.pc"
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
@@ -36,7 +37,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-tk' '--without-gmp' '--with-opt-dir=/opt/local' '--with-openssl-include=/opt/local/libexec/openssl10/include' '--with-openssl-lib=/opt/local/libexec/openssl10/lib' '--program-suffix=2.1' '--with-rubylibprefix=/opt/local/lib/ruby2.1' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl10/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++ -arch x86_64' 'PKG_CONFIG_PATH=/opt/local/libexec/openssl10/lib/pkgconfig'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-tk' '--without-gmp' '--with-opt-dir=/opt/local' '--with-openssl-include=/opt/local/libexec/openssl10/include' '--with-openssl-lib=/opt/local/libexec/openssl10/lib' '--program-suffix=2.2' '--with-rubylibprefix=/opt/local/lib/ruby2.2' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl10/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++ -arch x86_64' 'PKG_CONFIG_PATH=/opt/local/libexec/openssl10/lib/pkgconfig'"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
@@ -45,7 +46,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.1.0"
+  CONFIG["ruby_version"] = "2.2.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin12"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -84,7 +85,7 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = ""
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wextra-tokens"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wdeprecated-declarations -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
@@ -95,7 +96,7 @@ module RbConfig
   CONFIG["INSTALLDOC"] = "nodoc"
   CONFIG["CAPITARGET"] = "nodoc"
   CONFIG["RDOCTARGET"] = "nodoc"
-  CONFIG["DTRACE_GLOMMED_OBJ"] = ""
+  CONFIG["DTRACE_REBUILD"] = ""
   CONFIG["DTRACE_OBJ"] = ""
   CONFIG["DTRACE_EXT"] = "d"
   CONFIG["EXECUTABLE_EXTS"] = ""
@@ -107,8 +108,9 @@ module RbConfig
   CONFIG["BTESTRUBY"] = "$(MINIRUBY)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.1"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.2"
   CONFIG["setup"] = "Setup"
+  CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip -A -n"
   CONFIG["TRY_LINK"] = ""
@@ -116,6 +118,7 @@ module RbConfig
   CONFIG["RPATHFLAG"] = ""
   CONFIG["LIBPATHFLAG"] = " -L%s"
   CONFIG["LINK_SO"] = "\n$(POSTLINK)"
+  CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
   CONFIG["DLEXT2"] = ""
   CONFIG["DLEXT"] = "bundle"
@@ -169,12 +172,13 @@ module RbConfig
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
   CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++"
-  CONFIG["CXX"] = "/usr/bin/clang++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl10/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl10/lib -Wl,-headerpad_max_install_names  -arch x86_64 -fstack-protector -L/opt/local/lib -L/opt/local/lib "
-  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration  -arch x86_64 -fno-common"
+  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl10/lib -Wl,-headerpad_max_install_names -fstack-protector -L/opt/local/lib -L/opt/local/lib "
+  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration -fno-common"
+  CONFIG["CXX"] = "/usr/bin/clang++"
   CONFIG["CC"] = "/usr/bin/clang"
+  CONFIG["NACL_LIB_PATH"] = ""
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
@@ -193,8 +197,8 @@ module RbConfig
   CONFIG["build_vendor"] = "apple"
   CONFIG["build_cpu"] = "x86_64"
   CONFIG["build"] = "x86_64-apple-darwin12"
-  CONFIG["RUBY_RELEASE_DATE"] = "2016-03-30"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.9"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.2.10"
+  CONFIG["HAVE_BASERUBY"] = "yes"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
@@ -222,7 +226,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&2.1&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&2.2&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -266,5 +270,4 @@ module RbConfig
     )
   end
 end
-autoload :Config, "rbconfig/obsolete.rb" # compatibility for ruby-1.8.4 and older.
 CROSS_COMPILING = nil unless defined? CROSS_COMPILING
